Procedual macros for crate rustdoc_copy.
The author of this crate is not good at English. Forgive me if the document is hard to read.
Macros
- doc_
file - Include Markdown file as given name module.
Attribute Macros
- doc_
share - Share documentation comment as given name module.